@@ -27,20 +27,22 @@ except FileNotFoundError:
     FONT='Consolas'
     SUPERCOLLIDER=""
     BOOT_ON_STARTUP=False
+    CHECK_FOR_UPDATE=True
     SC3_PLUGINS=False
     MAX_CHANNELS=2
     SAMPLES_DIR=""
     GET_SC_INFO=True
-    USE_ALPHA=False
+    USE_ALPHA=True
     ALPHA_VALUE=0.8
     MENU_ON_STARTUP=True
     TRANSPARENT_ON_STARTUP=False
     RECOVER_WORK=True
     LINE_NUMBER_MARKER_OFFSET=0
+    AUTO_COMPLETE_BRACKETS=True
     CPU_USAGE=2 # 0=low, 1=medium, 2=high
-    CLOCK_LATENCY=0 #0=low, 1=medium, 2=high
+    CLOCK_LATENCY=0 # 0=low, 1=medium, 2=high
     FORWARD_ADDRESS=''
-    FORWARD_PORT=None
+    FORWARD_PORT=0
 
     # Text colours
     # ------------------
